@@ -42,9 +42,10 @@ static int wait_for_renderer();
 static int pdf_count_pages(const char *filename)
 {
     char gscommand[CMDLINE_MAX];
-    char output[31] = "";
+    char output[63] = "";
     int pagecount;
     size_t bytes;
+    char *p;
 
     snprintf(gscommand, CMDLINE_MAX, "%s -dNODISPLAY -q -c "
 	     "'/pdffile (%s) (r) file runpdfbegin (PageCount: ) print "
@@ -55,11 +56,20 @@ static int pdf_count_pages(const char *filename)
     if (!pd)
       rip_die(EXIT_STARVED, "Failed to execute ghostscript to determine number of input pages!\n");
 
-    bytes = fread_or_die(output, 1, 31, pd);
+    bytes = fread_or_die(output, 1, 63, pd);
     pclose(pd);
 
-    if (bytes <= 0 || sscanf(output, "PageCount: %d", &pagecount) < 1)
-      pagecount = -1;
+    p = output;
+    pagecount = -1;
+    while (bytes > 0) {
+      if (sscanf(p, "PageCount: %d", &pagecount) >= 1)
+	break;
+      p = memchr(p, '\n', bytes);
+      if (p == NULL)
+	break;
+      p ++;
+      bytes = output + bytes - p;
+    }
 
     return pagecount;
 }
@@ -242,9 +252,14 @@ static int print_pdf_file(const char *filename)
 
     page_count = pdf_count_pages(filename);
 
-    if (page_count <= 0)
+    if (page_count < 0)
         rip_die(EXIT_JOBERR, "Unable to determine number of pages, page count: %d\n", page_count);
     _log("File contains %d pages\n", page_count);
+    if (page_count == 0)
+    {
+        _log("No pages left, outputting empty file.\n");
+        return 1;
+    }
 
     optionset_copy_values(optionset("header"), optionset("currentpage"));
     optionset_copy_values(optionset("currentpage"), optionset("previouspage"));
